Class: Asciidoctor::Stylesheets
- Inherits:
-
Object
- Object
- Asciidoctor::Stylesheets
- Defined in:
- lib/asciidoctor/stylesheets.rb
Overview
QUESTION create method for user stylesheet?
Constant Summary collapse
- DEFAULT_STYLESHEET_NAME =
'asciidoctor.css'- STYLESHEETS_DIR =
::File.join DATA_DIR, 'stylesheets'
Class Method Summary collapse
Instance Method Summary collapse
-
#coderay_stylesheet_data ⇒ Object
Read the contents of the default CodeRay stylesheet.
- #coderay_stylesheet_name ⇒ Object
-
#embed_coderay_stylesheet ⇒ String
deprecated
Deprecated.
Do not use this in new code, and replace it when updating old code.
-
#embed_primary_stylesheet ⇒ String
deprecated
Deprecated.
Do not use this in new code, and replace it when updating old code.
-
#embed_pygments_stylesheet(style = nil) ⇒ String
deprecated
Deprecated.
Do not use this in new code, and replace it when updating old code.
-
#primary_stylesheet_data ⇒ Object
Read the contents of the default Asciidoctor stylesheet.
- #primary_stylesheet_name ⇒ Object
-
#pygments_stylesheet_data(style = nil) ⇒ Object
Generate the Pygments stylesheet with the specified style.
- #pygments_stylesheet_name(style = nil) ⇒ Object
- #write_coderay_stylesheet(target_dir = '.') ⇒ Object
- #write_primary_stylesheet(target_dir = '.') ⇒ Object
- #write_pygments_stylesheet(target_dir = '.', style = nil) ⇒ Object
Class Method Details
.instance ⇒ Object
13 14 15 |
# File 'lib/asciidoctor/stylesheets.rb', line 13 def self.instance @__instance__ end |
Instance Method Details
#coderay_stylesheet_data ⇒ Object
Read the contents of the default CodeRay stylesheet
returns the [String] CodeRay stylesheet data
48 49 50 |
# File 'lib/asciidoctor/stylesheets.rb', line 48 def coderay_stylesheet_data (SyntaxHighlighter.for 'coderay').read_stylesheet end |
#coderay_stylesheet_name ⇒ Object
41 42 43 |
# File 'lib/asciidoctor/stylesheets.rb', line 41 def coderay_stylesheet_name (SyntaxHighlighter.for 'coderay').stylesheet_basename end |
#embed_coderay_stylesheet ⇒ String
Deprecated.
Do not use this in new code, and replace it when updating old code.
Generate code to embed the CodeRay stylesheet