Method: Asciidoctor::AbstractBlock#content_model
- Defined in:
- lib/asciidoctor/abstract_block.rb
#content_model ⇒ Object
Describes the type of content this block accepts and how it should be converted. Acceptable values are:
-
:compound - this block contains other blocks
-
:simple - this block holds a paragraph of prose that receives normal substitutions
-
:verbatim - this block holds verbatim text (displayed “as is”) that receives verbatim substitutions
-
:raw - this block holds unprocessed content passed directly to the output with no substitutions applied
-
:empty - this block has no content
16 17 18 |
# File 'lib/asciidoctor/abstract_block.rb', line 16 def content_model @content_model end |